@@ -8,24 +8,25 @@
 
 #include "kextendableitemdelegate.h"
 
+#include <QApplication>
 #include <QModelIndex>
+#include <QPainter>
 #include <QScrollBar>
 #include <QTreeView>
-#include <QPainter>
-#include <QApplication>
 
-class Q_DECL_HIDDEN KExtendableItemDelegate::Private
+class KExtendableItemDelegatePrivate
 {
 public:
-    Private(KExtendableItemDelegate *parent) :
-        q(parent),
-        stateTick(0),
-        cachedStateTick(-1),
-        cachedRow(-20), //Qt uses -1 for invalid indices
-        extender(nullptr),
+    KExtendableItemDelegatePrivate(KExtendableItemDelegate *parent)
+        : q(parent)
+        , stateTick(0)
+        , cachedStateTick(-1)
+        , cachedRow(-20)
+        , // Qt uses -1 for invalid indices
         extenderHeight(0)
 
-    {}
+    {
+    }
 
     void _k_extenderDestructionHandler(QObject *destroyed);
     void _k_verticalScroll();
@@ -34,14 +35,14 @@ public:
     QModelIndex indexOfExtendedColumnInSameRow(const QModelIndex &index) const;
     void scheduleUpdateViewLayout();
 
-    KExtendableItemDelegate *q;
+    KExtendableItemDelegate *const q;
 
     /**
      * Delete all active extenders
      */
     void deleteExtenders();
 
-    //this will trigger a lot of auto-casting QModelIndex <-> QPersistentModelIndex
+    // this will trigger a lot of auto-casting QModelIndex <-> QPersistentModelIndex
     QHash<QPersistentModelIndex, QWidget *> extenders;
     QHash<QWidget *, QPersistentModelIndex> extenderIndices;
     QMultiHash<QWidget *, QPersistentModelIndex> deletionQueue;
@@ -51,22 +52,18 @@ public:
     int cachedStateTick;
     int cachedRow;
     QModelIndex cachedParentIndex;
-    QWidget *extender;
+    QWidget *extender = nullptr;
     int extenderHeight;
 };
 
 KExtendableItemDelegate::KExtendableItemDelegate(QAbstractItemView *parent)
-    : QStyledItemDelegate(parent),
-      d(new Private(this))
+    : QStyledItemDelegate(parent)
+    , d(new KExtendableItemDelegatePrivate(this))
 {
-    connect(parent->verticalScrollBar(), SIGNAL(valueChanged(int)),
-            this, SLOT(_k_verticalScroll()));
+    connect(parent->verticalScrollBar(), SIGNAL(valueChanged(int)), this, SLOT(_k_verticalScroll()));
 }
 
-KExtendableItemDelegate::~KExtendableItemDelegate()
-{
-    delete d;
-}
+KExtendableItemDelegate::~KExtendableItemDelegate() = default;
 
 void KExtendableItemDelegate::extendItem(QWidget *ext, const QModelIndex &index)
 {
@@ -75,11 +72,11 @@ void KExtendableItemDelegate::extendItem(QWidget *ext, const QModelIndex &index)
     if (!ext || !index.isValid()) {
         return;
     }
-    //maintain the invariant "zero or one extender per row"
+    // maintain the invariant "zero or one extender per row"
     d->stateTick++;
     contractItem(d->indexOfExtendedColumnInSameRow(index));
     d->stateTick++;
-    //reparent, as promised in the docs
+    // reparent, as promised in the docs
     QAbstractItemView *aiv = qobject_cast<QAbstractItemView *>(parent());
     if (!aiv) {
         return;
@@ -87,8 +84,8 @@ void KExtendableItemDelegate::extendItem(QWidget *ext, const QModelIndex &index)
     ext->setParent(aiv->viewport());
     d->extenders.insert(index, ext);
     d->extenderIndices.insert(ext, index);
-    connect(ext, SIGNAL(destroyed(QObject*)), this, SLOT(_k_extenderDestructionHandler(QObject*)));
-    emit extenderCreated(ext, index);
+    connect(ext, SIGNAL(destroyed(QObject *)), this, SLOT(_k_extenderDestructionHandler(QObject *)));
+    Q_EMIT extenderCreated(ext, index);
     d->scheduleUpdateViewLayout();
 }
 
@@ -115,8 +112,8 @@ void KExtendableItemDelegate::contractAll()
     d->deleteExtenders();
 }
 
-//slot
-void KExtendableItemDelegate::Private::_k_extenderDestructionHandler(QObject *destroyed)
+// slot
+void KExtendableItemDelegatePrivate::_k_extenderDestructionHandler(QObject *destroyed)
 {
     // qDebug() << "Removing extender at " << destroyed;
 
@@ -124,18 +121,16 @@ void KExtendableItemDelegate::Private::_k_extenderDestructionHandler(QObject *de
     stateTick++;
 
     QPersistentModelIndex persistentIndex = deletionQueue.take(extender);
-    if (persistentIndex.isValid() &&
-            q->receivers(SIGNAL(extenderDestroyed(QWidget*,QModelIndex)))) {
-
+    if (persistentIndex.isValid() && q->receivers(SIGNAL(extenderDestroyed(QWidget *, QModelIndex))) != 0) {
         QModelIndex index = persistentIndex;
-        emit q->extenderDestroyed(extender, index);
+        Q_EMIT q->extenderDestroyed(extender, index);
     }
 
     scheduleUpdateViewLayout();
 }
 
-//slot
-void KExtendableItemDelegate::Private::_k_verticalScroll()
+// slot
+void KExtendableItemDelegatePrivate::_k_verticalScroll()
 {
     for (QWidget *extender : qAsConst(extenders)) {
         // Fast scrolling can lead to artifacts where extenders stay in the viewport
@@ -164,8 +159,7 @@ QSize KExtendableItemDelegate::sizeHint(const QStyleOptionViewItem &option, cons
         ret = QStyledItemDelegate::sizeHint(option, index);
     }
 
-    bool showExtensionIndicator = index.model() ?
-                                  index.model()->data(index, ShowExtensionIndicatorRole).toBool() : false;
+    bool showExtensionIndicator = index.model() ? index.model()->data(index, ShowExtensionIndicatorRole).toBool() : false;
     if (showExtensionIndicator) {
         ret.rwidth() += d->extendPixmap.width();
     }
@@ -213,13 +207,12 @@ void KExtendableItemDelegate::paint(QPainter *painter, const QStyleOptionViewIte
         indicatorY = option.rect.top() + ((option.rect.height() - d->extendPixmap.height()) >> 1);
     }
 
-    //fast path
+    // fast path
     if (d->extenders.isEmpty()) {
         QStyledItemDelegate::paint(painter, itemOption, index);
         if (showExtensionIndicator) {
             painter->save();
-            QApplication::style()->drawPrimitive(QStyle::PE_PanelItemViewItem, &indicatorOption,
-                                                 painter);
+            QApplication::style()->drawPrimitive(QStyle::PE_PanelItemViewItem, &indicatorOption, painter);
             painter->restore();
             painter->drawPixmap(indicatorX, indicatorY, d->extendPixmap);
         }
@@ -229,9 +222,10 @@ void KExtendableItemDelegate::paint(QPainter *painter, const QStyleOptionViewIte
     int row = index.row();
     QModelIndex parentIndex = index.parent();
 
-    //indexOfExtendedColumnInSameRow() is very expensive, try to avoid calling it.
-    if (row != d->cachedRow || d->cachedStateTick != d->stateTick
-            || d->cachedParentIndex != parentIndex) {
+    // indexOfExtendedColumnInSameRow() is very expensive, try to avoid calling it.
+    if (row != d->cachedRow //
+        || d->cachedStateTick != d->stateTick //
+        || d->cachedParentIndex != parentIndex) {
         d->extender = d->extenders.value(d->indexOfExtendedColumnInSameRow(index));
         d->cachedStateTick = d->stateTick;
         d->cachedRow = row;
@@ -245,39 +239,36 @@ void KExtendableItemDelegate::paint(QPainter *painter, const QStyleOptionViewIte
         QStyledItemDelegate::paint(painter, itemOption, index);
         if (showExtensionIndicator) {
             painter->save();
-            QApplication::style()->drawPrimitive(QStyle::PE_PanelItemViewItem, &indicatorOption,
-                                                 painter);
+            QApplication::style()->drawPrimitive(QStyle::PE_PanelItemViewItem, &indicatorOption, painter);
             painter->restore();
             painter->drawPixmap(indicatorX, indicatorY, d->extendPixmap);
         }
         return;
     }
 
-    //an extender is present - make two rectangles: one to paint the original item, one for the extender
+    // an extender is present - make two rectangles: one to paint the original item, one for the extender
     if (isExtended(index)) {
         QStyleOptionViewItem extOption(option);
         initStyleOption(&extOption, index);
         extOption.rect = extenderRect(d->extender, option, index);
         updateExtenderGeometry(d->extender, extOption, index);
-        //if we show it before, it will briefly flash in the wrong location.
-        //the downside is, of course, that an api user effectively can't hide it.
+        // if we show it before, it will briefly flash in the wrong location.
+        // the downside is, of course, that an api user effectively can't hide it.
         d->extender->show();
     }
 
     indicatorOption.rect.setHeight(option.rect.height() - d->extenderHeight);
     itemOption.rect.setHeight(option.rect.height() - d->extenderHeight);
-    //tricky:make sure that the modified options' rect really has the
-    //same height as the unchanged option.rect if no extender is present
+    // tricky:make sure that the modified options' rect really has the
+    // same height as the unchanged option.rect if no extender is present
     //(seems to work OK)
     QStyledItemDelegate::paint(painter, itemOption, index);
 
     if (showExtensionIndicator) {
-        //indicatorOption's height changed, change this too
-        indicatorY = indicatorOption.rect.top() + ((indicatorOption.rect.height() -
-                     d->extendPixmap.height()) >> 1);
+        // indicatorOption's height changed, change this too
+        indicatorY = indicatorOption.rect.top() + ((indicatorOption.rect.height() - d->extendPixmap.height()) >> 1);
         painter->save();
-        QApplication::style()->drawPrimitive(QStyle::PE_PanelItemViewItem, &indicatorOption,
-                                             painter);
+        QApplication::style()->drawPrimitive(QStyle::PE_PanelItemViewItem, &indicatorOption, painter);
         painter->restore();
 
         if (d->extenders.contains(index)) {
@@ -318,20 +309,20 @@ QRect KExtendableItemDelegate::extenderRect(QWidget *extender, const QStyleOptio
     return rect;
 }
 
-QSize KExtendableItemDelegate::Private::maybeExtendedSize(const QStyleOptionViewItem &option, const QModelIndex &index) const
+QSize KExtendableItemDelegatePrivate::maybeExtendedSize(const QStyleOptionViewItem &option, const QModelIndex &index) const
 {
     QWidget *extender = extenders.value(index);
     QSize size(q->QStyledItemDelegate::sizeHint(option, index));
     if (!extender) {
         return size;
     }
-    //add extender height to maximum height of any column in our row
+    // add extender height to maximum height of any column in our row
     int itemHeight = size.height();
 
     int row = index.row();
     int thisColumn = index.column();
 
-    //this is quite slow, but Qt is smart about when to call sizeHint().
+    // this is quite slow, but Qt is smart about when to call sizeHint().
     for (int column = 0; index.model()->columnCount() < column; column++) {
         if (column == thisColumn) {
             continue;
@@ -343,19 +334,19 @@ QSize KExtendableItemDelegate::Private::maybeExtendedSize(const QStyleOptionView
         itemHeight = qMax(itemHeight, q->QStyledItemDelegate::sizeHint(option, neighborIndex).height());
     }
 
-    //we only want to reserve vertical space, the horizontal extender layout is our private business.
+    // we only want to reserve vertical space, the horizontal extender layout is our private business.
     size.rheight() = itemHeight + extender->sizeHint().height();
     return size;
 }
 
-QModelIndex KExtendableItemDelegate::Private::indexOfExtendedColumnInSameRow(const QModelIndex &index) const
+QModelIndex KExtendableItemDelegatePrivate::indexOfExtendedColumnInSameRow(const QModelIndex &index) const
 {
     const QAbstractItemModel *const model = index.model();
     const QModelIndex parentIndex(index.parent());
     const int row = index.row();
     const int columnCount = model->columnCount();
 
-    //slow, slow, slow
+    // slow, slow, slow
     for (int column = 0; column < columnCount; column++) {
         QModelIndex indexOfExt(model->index(row, column, parentIndex));
         if (extenders.value(indexOfExt)) {
@@ -366,36 +357,31 @@ QModelIndex KExtendableItemDelegate::Private::indexOfExtendedColumnInSameRow(con
     return QModelIndex();
 }
 
-void KExtendableItemDelegate::updateExtenderGeometry(QWidget *extender, const QStyleOptionViewItem &option,
-        const QModelIndex &index) const
+void KExtendableItemDelegate::updateExtenderGeometry(QWidget *extender, const QStyleOptionViewItem &option, const QModelIndex &index) const
 {
     Q_UNUSED(index);
     extender->setGeometry(option.rect);
 }
 
-void KExtendableItemDelegate::Private::deleteExtenders()
+void KExtendableItemDelegatePrivate::deleteExtenders()
 {
     for (QWidget *ext : qAsConst(extenders)) {
         ext->hide();
         ext->deleteLater();
     }
-#if QT_VERSION < QT_VERSION_CHECK(5, 13, 0)
-    deletionQueue += extenderIndices;
-#else
     deletionQueue.unite(extenderIndices);
-#endif
     extenders.clear();
     extenderIndices.clear();
 }
 
-//make the view re-ask for sizeHint() and redisplay items with their new size
+// make the view re-ask for sizeHint() and redisplay items with their new size
 //### starting from Qt 4.4 we could emit sizeHintChanged() instead
-void KExtendableItemDelegate::Private::scheduleUpdateViewLayout()
+void KExtendableItemDelegatePrivate::scheduleUpdateViewLayout()
 {
     QAbstractItemView *aiv = qobject_cast<QAbstractItemView *>(q->parent());
-    //prevent crashes during destruction of the view
+    // prevent crashes during destruction of the view
     if (aiv) {
-        //dirty hack to call aiv's protected scheduleDelayedItemsLayout()
+        // dirty hack to call aiv's protected scheduleDelayedItemsLayout()
         aiv->setRootIndex(aiv->rootIndex());
     }
 }
